@@ -8,7 +8,7 @@
 
 #include <asm/types.h>          /* For __uXX types */
 
-#define IP_VS_VERSION_CODE            0x000908
+#define IP_VS_VERSION_CODE            0x000909
 #define NVERSION(version)                       \
 	(version >> 16) & 0xFF,                 \
 	(version >> 8) & 0xFF,                  \
@@ -892,7 +892,7 @@ __ip_vs_get_out_rt(struct ip_vs_conn *cp, u32 rtos)
 	} else {
 		if (ip_route_output(&rt, cp->daddr, 0, rtos, 0)) {
 			IP_VS_DBG_RL("ip_route_output error, dest: "
-				     "%u.%u.%u.%u\n", NIPQUAD(dest->addr));
+				     "%u.%u.%u.%u\n", NIPQUAD(cp->daddr));
 			return NULL;
 		}
 	}
