@@ -5,7 +5,7 @@
  *              high-performance and highly available server based on a
  *              cluster of servers.
  *
- * Version:     $Id: ip_vs_conn.c,v 1.23 2001/11/23 14:34:10 wensong Exp $
+ * Version:     $Id: ip_vs_conn.c,v 1.24 2002/01/24 14:23:48 wensong Exp $
  *
  * Authors:     Wensong Zhang <wensong@linuxvirtualserver.org>
  *              Peter Kese <peter.kese@ijs.si>
@@ -138,10 +138,7 @@ int ip_vs_conn_hash(struct ip_vs_conn *cp)
 		return 0;
 	}
 
-	/*
-	 *	Hash by proto,d{addr,port},
-	 *      which are client address and port in IPVS.
-	 */
+	/* Hash by protocol, client address and port */
 	hash = ip_vs_conn_hashkey(cp->protocol, cp->caddr, cp->cport);
 
 	ct_write_lock(hash);
@@ -170,9 +167,7 @@ int ip_vs_conn_unhash(struct ip_vs_conn *cp)
 		return 0;
 	}
 
-	/*
-	 * Remove it from the list and decrease its reference counter.
-	 */
+	/* unhash it and decrease its reference counter */
 	hash = ip_vs_conn_hashkey(cp->protocol, cp->caddr, cp->cport);
 	ct_write_lock(hash);
 
@@ -191,7 +186,6 @@ int ip_vs_conn_unhash(struct ip_vs_conn *cp)
  *  Called for pkts coming from OUTside-to-INside.
  *	s_addr, s_port: pkt source address (foreign host)
  *	d_addr, d_port: pkt dest address (load balancer)
- *  Caller must lock tables
  */
 static inline struct ip_vs_conn *__ip_vs_conn_in_get
 (int protocol, __u32 s_addr, __u16 s_port, __u32 d_addr, __u16 d_port)
@@ -246,7 +240,6 @@ struct ip_vs_conn *ip_vs_conn_in_get
  *  Called for pkts coming from inside-to-OUTside.
  *	s_addr, s_port: pkt source address (inside host)
  *	d_addr, d_port: pkt dest address (foreign host)
- *  Caller must lock tables
  */
 struct ip_vs_conn *ip_vs_conn_out_get
 (int protocol, __u32 s_addr, __u16 s_port, __u32 d_addr, __u16 d_port)
@@ -567,14 +560,14 @@ int ip_vs_set_state(struct ip_vs_conn *cp,
 
 	spin_lock(&cp->lock);
 	switch (iph->protocol) {
-	case IPPROTO_ICMP:
-		ret = vs_set_state_timeout(cp, IP_VS_S_ICMP);
+	case IPPROTO_TCP:
+		ret = vs_tcp_state(cp, state_off, tp);
 		break;
 	case IPPROTO_UDP:
 		ret = vs_set_state_timeout(cp, IP_VS_S_UDP);
 		break;
-	case IPPROTO_TCP:
-		ret = vs_tcp_state(cp, state_off, tp);
+	case IPPROTO_ICMP:
+		ret = vs_set_state_timeout(cp, IP_VS_S_ICMP);
 		break;
 	default:
 		ret = -1;
@@ -671,10 +664,9 @@ static int ip_vs_nat_xmit(struct sk_buff *skb, struct ip_vs_conn *cp)
 	/*
 	 * If it has ip_vs_app helper, the helper may change the payload,
 	 * so it needs full checksum checking and checksum caculation.
-	 * If not, we think the payload checksum is OK, only the header
-	 * (such as IP address and port number) is changed, so it is fast
-	 * to do incremental checksum update, and let the destination host
-	 * do final checksum checking.
+	 * If not, only the header (such as IP address and port number)
+	 * will be changed, so it is fast to do incremental checksum update,
+	 * and let the destination host  do final checksum checking.
 	 */
 
 	if (cp->app && skb_is_nonlinear(skb)
@@ -708,7 +700,7 @@ static int ip_vs_nat_xmit(struct sk_buff *skb, struct ip_vs_conn *cp)
 	}
 
 	/*
-	 *  Check if it is no_cport connection (VS/NAT only)...
+	 *  Check if it is no_cport connection ...
 	 */
 	if (cp->flags & IP_VS_CONN_F_NO_CPORT) {
 		atomic_dec(&ip_vs_conn_no_cport_cnt);
@@ -1096,8 +1088,8 @@ static inline void ip_vs_unbind_dest(struct ip_vs_conn *cp)
 
 /*
  *  Checking if the destination of a connection template is available.
- *  If available, return 1, otherwise return 0 and invalidate this
- *  connection template.
+ *  If available, return 1, otherwise invalidate this connection
+ *  template and return 0.
  */
 int ip_vs_check_template(struct ip_vs_conn *ct)
 {
@@ -1214,7 +1206,7 @@ static void ip_vs_conn_expire(unsigned long data)
 
 
 /*
- *  Create a new connection entry for IPVS and hash it into the ip_vs_conn_tab.
+ *  Create a new connection entry and hash it into the ip_vs_conn_tab.
  */
 struct ip_vs_conn *
 ip_vs_conn_new(int proto, __u32 caddr, __u16 cport, __u32 vaddr, __u16 vport,
@@ -1485,9 +1477,8 @@ int ip_vs_conn_init(void)
 	 * Allocate the connection hash table and initialize its list heads
 	 */
 	ip_vs_conn_tab = vmalloc(IP_VS_CONN_TAB_SIZE*sizeof(struct list_head));
-	if (!ip_vs_conn_tab) {
+	if (!ip_vs_conn_tab)
 		return -ENOMEM;
-	}
 
 	/* Allocate ip_vs_conn slab cache */
 	ip_vs_conn_cachep = kmem_cache_create("ip_vs_conn",
