@@ -5,7 +5,7 @@
  *              high-performance and highly available server based on a
  *              cluster of servers.
  *
- * Version:     $Id: ip_vs_ctl.c,v 1.23 2001/12/11 12:41:29 wensong Exp $
+ * Version:     $Id: ip_vs_ctl.c,v 1.24 2002/01/24 14:23:48 wensong Exp $
  *
  * Authors:     Wensong Zhang <wensong@linuxvirtualserver.org>
  *              Peter Kese <peter.kese@ijs.si>
@@ -1677,12 +1677,15 @@ do_ip_vs_set_ctl(struct sock *sk, int cmd, void *user, unsigned int len)
 	 * Check the size of mm, no overflow...
 	 * len > 128000 is a sanity check.
 	 */
-	if (len < sizeof(struct ip_vs_rule_user) || len > 128000) {
-		IP_VS_ERR("IP_VS_SO_INSERT/DELETE: len %u < %u\n",
+	if (len < sizeof(struct ip_vs_rule_user)) {
+		IP_VS_ERR("set_ctl: len %u < %u\n",
 			  len, sizeof(struct ip_vs_rule_user));
 		return -EINVAL;
+	} else if (len > 128000) {
+		IP_VS_ERR("set_ctl: len %u > 128000\n", len);
+		return -EINVAL;
 	} else if ((urule = kmalloc(len, GFP_KERNEL)) == NULL) {
-		IP_VS_ERR("IP_VS_SO_INSERT/DELETE: oom for len %u\n", len);
+		IP_VS_ERR("set_ctl: no mem for len %u\n", len);
 		return -ENOMEM;
 	} else if (copy_from_user(urule, user, len) != 0) {
 		ret = -EFAULT;
