@@ -1,7 +1,7 @@
 /*
  * IP_VS        ftp application module
  *
- * Version:	$Id: ip_vs_ftp.c,v 1.9 2001/11/04 08:58:43 wensong Exp $
+ * Version:	$Id: ip_vs_ftp.c,v 1.10 2001/11/23 14:34:10 wensong Exp $
  *
  * Authors:	Wensong Zhang <wensong@linuxvirtualserver.org>
  *
@@ -65,14 +65,14 @@ static int ip_vs_ftp_pasv;
 
 
 static int
-ip_vs_ftp_init_conn(struct ip_vs_app *mapp, struct ip_vs_conn *cp)
+ip_vs_ftp_init_conn(struct ip_vs_app *vapp, struct ip_vs_conn *cp)
 {
 	return 0;
 }
 
 
 static int
-ip_vs_ftp_done_conn(struct ip_vs_app *mapp, struct ip_vs_conn *cp)
+ip_vs_ftp_done_conn(struct ip_vs_app *vapp, struct ip_vs_conn *cp)
 {
 	return 0;
 }
@@ -137,10 +137,9 @@ static int ip_vs_ftp_get_addrport(char *data, char *data_limit,
  *   "227 Entering Passive Mode (xxx,xxx,xxx,xxx,ppp,ppp)".
  * xxx,xxx,xxx,xxx is the server address, ppp,ppp is the server port number.
  */
-static int ip_vs_ftp_out(struct ip_vs_app *mapp,
-			 struct ip_vs_conn *cp, struct sk_buff **skb_p)
+static int ip_vs_ftp_out(struct ip_vs_app *vapp,
+			 struct ip_vs_conn *cp, struct sk_buff *skb)
 {
-	struct sk_buff *skb;
 	struct iphdr *iph;
 	struct tcphdr *th;
 	char *data, *data_limit;
@@ -157,7 +156,6 @@ static int ip_vs_ftp_out(struct ip_vs_app *mapp,
 		return 0;
 
 	if (cp->app_data == &ip_vs_ftp_pasv) {
-		skb = *skb_p;
 		iph = skb->nh.iph;
 		th = (struct tcphdr *)&(((char *)iph)[iph->ihl*4]);
 		data = (char *)th + (th->doff << 2);
@@ -240,10 +238,9 @@ static int ip_vs_ftp_out(struct ip_vs_app *mapp,
  * port, so that the active ftp data connection from the server can reach
  * the client.
  */
-static int ip_vs_ftp_in(struct ip_vs_app *mapp,
-			struct ip_vs_conn *cp, struct sk_buff **skb_p)
+static int ip_vs_ftp_in(struct ip_vs_app *vapp,
+			struct ip_vs_conn *cp, struct sk_buff *skb)
 {
-	struct sk_buff *skb;
 	struct iphdr *iph;
 	struct tcphdr *th;
 	char *data, *data_start, *data_limit;
@@ -259,7 +256,6 @@ static int ip_vs_ftp_in(struct ip_vs_app *mapp,
 	/*
 	 * Detecting whether it is passive
 	 */
-	skb = *skb_p;
 	iph = skb->nh.iph;
 	th = (struct tcphdr *)&(((char *)iph)[iph->ihl*4]);
 
