@@ -1,7 +1,7 @@
 /*
  * IPVS:        Locality-Based Least-Connection with Replication scheduler
  *
- * Version:     $Id: ip_vs_lblcr.c,v 1.8 2001/10/19 15:05:17 wensong Exp $
+ * Version:     $Id: ip_vs_lblcr.c,v 1.9 2001/12/11 12:41:29 wensong Exp $
  *
  * Authors:     Wensong Zhang <wensong@gnuchina.org>
  *
@@ -122,16 +122,11 @@ ip_vs_dest_set_insert(struct ip_vs_dest_set *set, struct ip_vs_dest *dest)
 
 	/* link it to the list */
 	write_lock(&set->lock);
-	if (set->list != NULL) {
-		e->next = set->list->next;
-		set->list = e;
-	} else {
-		e->next = NULL;
-		set->list = e;
-	}
+	e->next = set->list;
+	set->list = e;
+	atomic_inc(&set->size);
 	write_unlock(&set->lock);
 
-	atomic_inc(&set->size);
 	set->lastmod = jiffies;
 	return e;
 }
@@ -533,7 +528,7 @@ static void ip_vs_lblcr_check_expire(unsigned long data)
 		goto out;
 	}
 
-	if (atomic_read(&tbl->entries) < tbl->max_size) {
+	if (atomic_read(&tbl->entries) <= tbl->max_size) {
 		tbl->counter++;
 		goto out;
 	}
@@ -594,7 +589,7 @@ ip_vs_lblcr_getinfo(char *buffer, char **start, off_t offset, int length)
 
 	for (i=0; i<IP_VS_LBLCR_TAB_SIZE; i++) {
 		l = &tbl->bucket[i];
-		read_lock(&tbl->lock);
+		read_lock_bh(&tbl->lock);
 		for (e=l->next; e!=l; e=e->next) {
 			char tbuf[16];
 			struct ip_vs_dest_list *d;
@@ -617,11 +612,11 @@ ip_vs_lblcr_getinfo(char *buffer, char **start, off_t offset, int length)
 			if (pos <= offset)
 				len=0;
 			if (pos >= offset+length) {
-				read_unlock(&tbl->lock);
+				read_unlock_bh(&tbl->lock);
 				goto done;
 			}
 		}
-		read_unlock(&tbl->lock);
+		read_unlock_bh(&tbl->lock);
 	}
 
   done:
